==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ADoubleBaseType.h <==
// public final class soot.jimple.parser.node.ADoubleBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f029ffe5daaf30da soot_jimple_parser_node_ADoubleBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ADoubleBaseType_H_
#define _JC_soot_jimple_parser_node_ADoubleBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDouble$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs	_jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$refs	_jc_soot_jimple_parser_node_ADoubleBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$object	_jc_soot_jimple_parser_node_ADoubleBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vmethods	_jc_soot_jimple_parser_node_ADoubleBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtable	_jc_soot_jimple_parser_node_ADoubleBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtype	_jc_soot_jimple_parser_node_ADoubleBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$_init$04034813823afdc5(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TDouble$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$getDouble$351388c6ad2156af(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$setDouble$3dabc10e226b31d3(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$getDouble$351388c6ad2156af;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$setDouble$3dabc10e226b31d3;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
	struct _jc_soot_jimple_parser_node_TDouble$object	*(*getDouble$351388c6ad2156af)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setDouble$3dabc10e226b31d3)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vmethods	soot_jimple_parser_node_ADoubleBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TDouble$object	*__5fdouble__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$refs {
    _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs	soot_jimple_parser_node_ADoubleBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs	soot_jimple_parser_node_ADoubleBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADoubleBaseType$object {
	_jc_soot_jimple_parser_node_ADoubleBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADoubleBaseType$vtype _jc_soot_jimple_parser_node_ADoubleBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADoubleBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADoubleBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADoubleBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ADoubleBaseType.h <==
// public final class soot.jimple.parser.node.ADoubleBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f029ffe5daaf30da soot_jimple_parser_node_ADoubleBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ADoubleBaseType_H_
#define _JC_soot_jimple_parser_node_ADoubleBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDouble$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs	_jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$refs	_jc_soot_jimple_parser_node_ADoubleBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs	_jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADoubleBaseType$object	_jc_soot_jimple_parser_node_ADoubleBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vmethods	_jc_soot_jimple_parser_node_ADoubleBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtable	_jc_soot_jimple_parser_node_ADoubleBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtype	_jc_soot_jimple_parser_node_ADoubleBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$_init$04034813823afdc5(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TDouble$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$getDouble$351388c6ad2156af(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADoubleBaseType$method$setDouble$3dabc10e226b31d3(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADoubleBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$getDouble$351388c6ad2156af;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$setDouble$3dabc10e226b31d3;
extern _jc_method _jc_soot_jimple_parser_node_ADoubleBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TDouble$object	*(*getDouble$351388c6ad2156af)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setDouble$3dabc10e226b31d3)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *, struct _jc_soot_jimple_parser_node_TDouble$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADoubleBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vmethods	soot_jimple_parser_node_ADoubleBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADoubleBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TDouble$object	*__5fdouble__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$refs {
    _jc_soot_jimple_parser_node_ADoubleBaseType$sub_refs	soot_jimple_parser_node_ADoubleBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ADoubleBaseType$sub_nonrefs	soot_jimple_parser_node_ADoubleBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADoubleBaseType$object {
	_jc_soot_jimple_parser_node_ADoubleBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADoubleBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADoubleBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADoubleBaseType$vtype _jc_soot_jimple_parser_node_ADoubleBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADoubleBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADoubleBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADoubleBaseType_H_ */
